@@ -1,15 +1,6 @@
-#define __GNOME_PRINT_MASTER_PREVIEW_C__
-
+/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /*
- *  Copyright (C) 2000-2001 Ximian Inc.
- *
- *  Authors:
- *    Michael Zucchi <notzed@helixcode.com>
- *    Miguel de Icaza <miguel@gnu.org>
- *    Lauris Kaplinski <lauris@ximian.com>
- *
- *  A system print preview window.  Based on print-preview.c
- *  from gnumeric.
+ *  gnome-print-master-preview.c: print preview window
  *
  *  This program is free software; you can redistribute it and/or
  *  modify it under the terms of the GNU Library General Public License
@@ -24,8 +15,17 @@
  *  You should have received a copy of the GNU Library General Public
  *  License along with this program; if not, write to the Free Software
  *  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ *
+ *  Authors:
+ *    Michael Zucchi <notzed@helixcode.com>
+ *    Miguel de Icaza <miguel@gnu.org>
+ *    Lauris Kaplinski <lauris@ximian.com>
+ *
+ *  Copyright (C) 2000-2002 Ximian Inc.
+ *
  */
 
+#define __GNOME_PRINT_MASTER_PREVIEW_C__
 #define noGPMP_VERBOSE
 
 #include <config.h>
@@ -45,14 +45,10 @@
 #include <gtk/gtkhbox.h>
 #include <gtk/gtkvbox.h>
 #include <gtk/gtklabel.h>
-#include <libgnomeprint/gnome-print-private.h>
-#include <libgnomeprint/gnome-print-meta.h>
+#include <libgnomeprint/private/gnome-print-private.h>
 
 #include "gnome-print-i18n.h"
 #include "gnome-print-master-preview.h"
-#if 0
-#include "gnome-print-preview-icons.h"
-#endif
 
 #define GPMP_ZOOM_IN_FACTOR M_SQRT2
 #define GPMP_ZOOM_OUT_FACTOR M_SQRT1_2
@@ -65,15 +61,6 @@
 #define TOOLBAR_BUTTON_BASE 5
 #define MOVE_INDEX 5
 
-#if 0
-typedef enum {
-	GPMP_MODE_MOVE,
-	GPMP_MODE_MOVE_DRAGGING,
-	GPMP_MODE_ZOOM_IN,
-	GPMP_MODE_ZOOM_OUT
-} GPMPPreviewMode;
-#endif
-
 struct _GnomePrintMasterPreview {
 	GtkWindow window;
 	/* Main VBox */
@@ -119,9 +106,6 @@ struct _GPMPPrivate {
 	gint current_page;
 	gint pagecount;
 
-#if 0
-	GPMPPreviewMode mode;
-#endif
 };
 
 static void gpmp_parse_layout (GnomePrintMasterPreview *mp);
@@ -139,9 +123,6 @@ render_page (GnomePrintMasterPreview *mp, gint page)
 	GnomePrintConfig *config;
 	ArtDRect region;
 	gdouble transform[6];
-	GnomePrintContext *meta;
-	const guchar *data;
-	gint len;
 
 	priv = (GPMPPrivate *) mp->priv;
 
@@ -184,10 +165,10 @@ goto_page (GnomePrintMasterPreview *mp, gint page)
 	g_snprintf (c, 32, "%d", page + 1);
 	gtk_entry_set_text (GTK_ENTRY (priv->page_entry), c);
 
-	gtk_widget_set_sensitive (mp->bpf, (page != 0));
-	gtk_widget_set_sensitive (mp->bpp, (page != 0));
-	gtk_widget_set_sensitive (mp->bpn, (page != (mp->pages - 1)));
-	gtk_widget_set_sensitive (mp->bpl, (page != (mp->pages - 1)));
+	gtk_widget_set_sensitive (mp->bpf, (page != 0) && priv->pagecount > 1);
+	gtk_widget_set_sensitive (mp->bpp, (page != 0) && priv->pagecount > 1);
+	gtk_widget_set_sensitive (mp->bpn, (page != (mp->pages - 1)) && priv->pagecount > 1);
+	gtk_widget_set_sensitive (mp->bpl, (page != (mp->pages - 1)) && priv->pagecount > 1);
 
 	if (page != priv->current_page) {
 		priv->current_page = page;
@@ -233,7 +214,7 @@ gpmp_zoom (GnomePrintMasterPreview *mp, gdouble factor, gboolean relative)
 
 	gtk_widget_set_sensitive (mp->bz1, (!CLOSE_ENOUGH (mp->zoom, 1.0)));
 	gtk_widget_set_sensitive (mp->bzi, (!CLOSE_ENOUGH (mp->zoom, GPMP_ZOOM_MAX)));
-	gtk_widget_set_sensitive (mp->bpn, (!CLOSE_ENOUGH (mp->zoom, GPMP_ZOOM_MIN)));
+	gtk_widget_set_sensitive (mp->bzo, (!CLOSE_ENOUGH (mp->zoom, GPMP_ZOOM_MIN)));
 
 	gnome_canvas_set_pixels_per_unit (priv->canvas, mp->zoom);
 }
@@ -426,38 +407,6 @@ preview_zoom_100_cmd (GtkToggleButton *t, GnomePrintMasterPreview *mp)
 	gpmp_zoom (mp, 1.0, FALSE);
 }
 
-#if 0
-static void
-preview_zoom_fit_wide_cmd (GtkToggleButton *t, GnomePrintMasterPreview *pmp)
-{
-	GPMPPrivate *priv;
-	gdouble zoom;
-	gint width;
-
-	priv = (GPMPPrivate *) pmp->priv;
-
-	width = GTK_WIDGET (priv->canvas)->allocation.width;
-
-	zoom = width / (mp->paw + 5.0 + PAGE_PAD);
-	gnome_canvas_set_pixels_per_unit (priv->canvas, zoom);
-}
-
-static void
-preview_zoom_fit_tall_cmd (GtkToggleButton *t, GnomePrintMasterPreview *mp)
-{
-	GPMPPrivate *priv;
-	gdouble zoom;
-	gint height;
-
-	priv = (GPMPPrivate *) pmp->priv;
-
-	height = GTK_WIDGET (priv->canvas)->allocation.height;
-
-	zoom = height / (mp->pah + 5.0 + PAGE_PAD);
-	gnome_canvas_set_pixels_per_unit (priv->canvas, zoom);
-}
-#endif
-
 static gint
 preview_canvas_key (GtkWidget *widget, GdkEventKey *event, gpointer data)
 {
@@ -479,14 +428,6 @@ preview_canvas_key (GtkWidget *widget, GdkEventKey *event, gpointer data)
 	case '1':
 		preview_zoom_100_cmd (0, pmp);
 		break;
-#if 0
-	case '2':		/* as good a key as any? */
-		preview_zoom_fit_wide_cmd (0, pmp);
-		break;
-	case '3':
-		preview_zoom_fit_tall_cmd (0, pmp);
-		break;
-#endif
 	case '+':
 	case '=':
 	case GDK_KP_Add:
@@ -840,8 +781,6 @@ gnome_print_master_preview_new (GnomePrintMaster *gpm, const guchar *title)
 {
 	GnomePrintMasterPreview *gpmp;
 	GPMPPrivate *priv;
-	GnomePrintConfig *config;
-	gint orientation;
 	gchar *text;
 
 	g_return_val_if_fail (gpm != NULL, NULL);
@@ -866,85 +805,22 @@ gnome_print_master_preview_new (GnomePrintMaster *gpm, const guchar *title)
 	gtk_signal_connect (GTK_OBJECT (priv->canvas), "realize",
 			    GTK_SIGNAL_FUNC (preview_zoom_fit_cmd), gpmp);
 
-	gpmp->pages = gnome_print_master_get_pages (gpm);
-
-	priv->pagecount = gnome_print_master_get_pages (gpm);
-
+	priv->pagecount = gpmp->pages = gnome_print_master_get_pages (gpm);
 	goto_page (gpmp, 0);
 	
-	text = g_strdup_printf ("%d", priv->pagecount);
-
-	gtk_label_set_text (GTK_LABEL (priv->last), text);
+	if (priv->pagecount == 0) {
+		priv->pagecount = 1;
+		text = g_strdup (_("<markup>1   <span foreground=\"red\" "
+				   "weight=\"ultrabold\" background=\"white\">"
+				   "No visible output was created.</span></markup>"));
+	} else 
+		text =  g_strdup_printf ("%d", priv->pagecount);
+	gtk_label_set_markup_with_mnemonic (GTK_LABEL (priv->last), text);
 	g_free (text);
 
 	return (GtkWidget *) gpmp;
 }
 
-#if 0
-/**
- * gnome_print_master_preview_new:
- * @gpm: A GnomePrintMaster which has been printed to and completed.
- * @title: Window title for the preview window.
- *
- * Create a new preview window widget.  The preview has inbuilt
- * buttons for zooming and panning, and menu's to print.
- *
- * Return value: A newly created GnomePrintMasterPreview widget.
- **/
-GnomePrintMasterPreview *
-gnome_print_master_preview_new (GnomePrintMaster *gpm, const guchar *title)
-{
-	return gnome_print_master_preview_new_with_orientation (gpm, title, FALSE);
-}
-
-/**
- * gnome_print_master_preview_new_with_orientation:
- * @gpm: A GnomePrintMaster which has been printed to and completed.
- * @title: Window title for the preview window.
- * @landscape: TRUE to rotate paper.
- *
- * Create a new preview window widget.  The preview has inbuilt
- * buttons for zooming and panning, and menu's to print.
- *
- * Return value: A newly created GnomePrintMasterPreview widget.
- **/
-GnomePrintMasterPreview *
-gnome_print_master_preview_new_with_orientation (GnomePrintMaster *gpm,
-						 const char *title,
-						 gboolean landscape)
-{
-	GnomePrintMasterPreview *pmp;
-	Private *pp;
-	char text[4 * sizeof (int)];
-
-	pmp = GNOME_PRINT_MASTER_PREVIEW (gtk_type_new (gnome_print_master_preview_get_type ()));
-
-	gnome_app_construct (GNOME_APP (pmp), "preview_window", title);
-
-	pp = pmp->priv;
-	pp->landscape = landscape;
-
-	pp->master = gpm;
-	gtk_object_ref (GTK_OBJECT (gpm));
-
-	create_toplevel (pmp);
-	create_preview_canvas (pmp);
-
-	/* this zooms to fit, once we know how big the window actually is */
-	gtk_signal_connect (GTK_OBJECT (pp->canvas), "realize",
-			    GTK_SIGNAL_FUNC (preview_zoom_fit_cmd), pmp);
-
-	pp->pagecount = gnome_print_master_get_pages (gpm);
-
-	goto_page (pmp, 0);
-
-	g_snprintf (text, 4 * sizeof (int), "/%d", pp->pagecount);
-	gtk_label_set_text (GTK_LABEL (pp->last), text);
-
-	return pmp;
-}
-#endif
-
 static void
 gpmp_parse_layout (GnomePrintMasterPreview *mp)
 {
